// --------------------------------------------------------------------------
//
// Media Feed Screen Saver
// http://blog.debin.net/Media-feed-screen-saver/
// damien@debin.net
//
// v0.1: initial release
//
// --------------------------------------------------------------------------
//
// Copyright (c) 2006 Damien Debin.
// All rights reserved.
// 
// This file is part of Media Feed Screen Saver.
// 
// Media Feed Screen Saver is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
// 
// Foobar is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Foobar; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
// --------------------------------------------------------------------------

using System;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;
using System.Globalization;
using System.Reflection;

namespace MediaFeedScreenSaver
{
    class Program : ApplicationContext
    {
        public const string ProgramURL = "http://blog.debin.net/Media-feed-screen-saver/";

        static public string VersionInfo;
        static TextWriterTraceListener logListener;

        int screenCount;

        private Program()
        {
            screenCount = Screen.AllScreens.Length;
            ScreenSaverForm[] ssf = new ScreenSaverForm[screenCount];

            int i = 0;
            foreach (Screen S in Screen.AllScreens)
            {
                ssf[i] = new ScreenSaverForm(S);
                ssf[i].FormClosed += new FormClosedEventHandler(OnFormClosed);
                ssf[i].Show();
                i++;
            }
        }

        private void OnFormClosed(object sender, EventArgs e)
        {
            // When a form is closed, decrement the count of open forms.

            // When the count gets to 0, exit the app by calling
            // ExitThread().
            screenCount--;
            if (screenCount == 0)
            {
                ExitThread();
            }
        }

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main(string[] args)
        {
            AssemblyName assemblyName = new AssemblyName(typeof(Program).Assembly.FullName);
            VersionInfo = assemblyName.Version.Major + "." + assemblyName.Version.Minor;

            StartLogger();

            if (args.Length > 0)
            {
                // Get the 2 character command line argument
                string arg = args[0].ToLower(CultureInfo.InvariantCulture).Trim().Substring(0, 2);
                switch (arg)
                {
                    case "/c":
                        // Show the options dialog
                        ShowOptions();
                        break;
                    case "/p":
                        // Don't do anything for preview
                        break;
                    case "/s":
                        // Show screensaver forms
                        if (args.Length > 1)
                        {
                            Properties.Settings.Default.RssFeedUri = args[1];
                        }
                        Application.Run(new Program());
                        break;
                    default:
                        MessageBox.Show("Invalid command line argument :" + arg, "Invalid Command Line Argument", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
            else
            {
                // If no arguments were passed in, show the options dialog
                ShowOptions();
            }

            StopLogger();
        }

        private static void StartLogger()
        {
            if (String.IsNullOrEmpty(Properties.Settings.Default.LogFileName)) return;

            StreamWriter logWriter = new StreamWriter(Properties.Settings.Default.LogFileName);
            logWriter.AutoFlush = true;
            logListener = new TextWriterTraceListener(logWriter);
            logListener.TraceOutputOptions |= TraceOptions.DateTime;
            Trace.Listeners.Add(logListener);
            Trace.AutoFlush = true;
        }

        private static void StopLogger()
        {
            if (logListener != null)
            {
                logListener.Flush();
                logListener.Dispose();
            }
        }

        private static void ShowOptions()
        {
            Application.Run(new OptionsForm());
        }
    }
}