// --------------------------------------------------------------------------
//
// Media Feed Screen Saver
// http://blog.debin.net/Media-feed-screen-saver/
// damien@debin.net
//
// --------------------------------------------------------------------------
//
// Copyright (c) 2006 Damien Debin.
// All rights reserved.
// 
// This file is part of Media Feed Screen Saver.
// 
// Media Feed Screen Saver is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
// 
// Foobar is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Foobar; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
// --------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Xml;
using System.Drawing;

namespace MediaFeedScreenSaver.Rss
{
    /// <remarks>
    /// Representation of a Channel element in an RSS 2.0 XML document.
    /// One or more RssChannels are contained in an RssFeed.
    /// </remarks>
    class RssChannel : IDisposable
    {
        private readonly string title;
        private readonly List<RssItem> items;

        public string Title { get { return title; } }
        public IList<RssItem> Items { get { return items.AsReadOnly(); } }

        /// <summary>
        /// Build an RSSChannel from an XmlNode representing a Channel element inside an RSS 2.0 XML document.
        /// </summary>
        /// <param name="channelNode"></param>
        internal RssChannel(XmlNode channelNode, Size requestedImageSize)
        {
            items = new List<RssItem>();
            title = channelNode.SelectSingleNode("title").InnerText;

            XmlNodeList itemNodes = channelNode.SelectNodes("item");
            foreach (XmlNode itemNode in itemNodes)
            {
                items.Add(new RssItem(itemNode, requestedImageSize));
            }
        }

        public void Dispose()
        {
            foreach (RssItem item in items)
            {
                item.Dispose();
            }
        }
    }
}
